#..........................................................................................
### ~~ R CODE TO ANALYSE MORTALITY SURVEYS PERFORMED BY FSNAU IN SOMALIA (2007-2011) ~~ ###

# Written by Francesco Checchi, LSHTM (September 2012)
# francesco.checchi@lshtm.ac.uk 


#..........................................................................................
### Preparatory

rm(list=ls(all=TRUE))

# working directory
setwd("C:/Users/Francesco/Desktop/Analysis/Validation of mortality estimates")
#setwd("H:/Francesco/LSHTM academic 2009-/FSNAU Somalia/Analysis/Validation of mortality estimates")

require(gtools)
require(survey)

#.........................................................................................
### Aggregate and classify survey datasets into one dataframe

# read in metadata on survey datasets to be validated
metadata <- read.csv("survey_validation_metadata.csv")


# read in, process and append the datasets
for (i in 1:nrow(metadata) ) {
		
		# read in the next dataset
		xi <- read.csv(paste(metadata[i, "survey_id"], ".csv", sep="") )
		# attribute to this dataset its unique survey_id from metadata
		xi[, "survey_id"] <- metadata[i, "survey_id"]
		
		# attribute the type of questionnaire to each dataset based on its variables		
		if ("d_older" %in% colnames(xi) ) {
			
			if ( "n_u5" %in% colnames(xi) ) xi[, "questionnaire"] <- "current_1"
				#"current_1": current household census with breakdown of u5 household members, no departures/arrivals/births, deaths categorised as 0-11m, 12-59m, older
				#             variables: cluster, hh, n, n_u5, d_011, d_1259, d_older
		
			else xi[, "questionnaire"] <- "current_2"
				#"current_2": current household census with no breakdown of u5 household members, no departures/arrivals/births, deaths categorised as 0-11m, 12-59m, older
				#             variables: cluster, hh, n, d_011, d_1259, d_older

			}
		
		if ( ("b" %in% colnames(xi) ) && ("l" %in% colnames(xi) ) && ("l_u5" %in% colnames(xi) ) 
		      && ("j" %in% colnames(xi) ) && ("j_u5" %in% colnames(xi) ) ) {
			
			if ( ( length(unique(xi[, "b"])) == 1 ) || ( length(unique(xi[, "l"])) == 1 ) || ( length(unique(xi[, "l_u5"])) == 1 ) 
			      || ( length(unique(xi[, "j"])) == 1 ) || ( length(unique(xi[, "j_u5"])) == 1 )  )
				  xi[, "questionnaire"] <- "current_3"
				#"current_3": current household census with breakdown of u5 household members, no departures/arrivals/births, deaths categorised as u5, older
				#             variables: cluster, hh, n, n_u5, j*, j_u5*, l*, l_u5*, b*, d, d_u5     *at least one of these variables not collected
		
			else xi[, "questionnaire"] <- "smart"
				#"smart": current household household census with breakdown of u5 household members, departures/arrivals/births, deaths categorised as u5, older
				#             variables: cluster, hh, n, n_u5, j, j_u5, l, l_u5, b, d, d_u5

			}
		
		if ( ("b" %in% colnames(xi) == TRUE) && ("l" %in% colnames(xi) == FALSE) ) {
			
				xi[, "questionnaire"] <- "current_3"
				# some surveys collect births but not departures/arrivals

			}
				
		
		
		
		# identify exhaustive surveys
		if (length(unique(xi[, "cluster"] ) ) == 1 ) xi[, "design"] <- "exhaustive" else xi[, "design"] <- "cluster"
		
		# bind new dataset to others		
		if (i == 1) { x <- xi } else { x <- smartbind(x, xi) }

}

# make sure numeric variables are actually numeric
for (i in c("cluster", "hh", "n", "n_u5", "j", "j_u5", "l", "l_u5", "b", "d", "d_u5", "d_older", "d_011", "d_1259") ) {
	
	x[, i] <- as.numeric(x[, i] )

	}
	
	
# add d, d_u5 variables to current_1 and current_2 questionnaire surveys
f.recode <- function (f.x) {	
	
	if ( ( f.x[["questionnaire"]] == "current_1") || (f.x[["questionnaire"]] == "current_2") )
	
	return (c (as.numeric(f.x[["d_011"]]) + as.numeric(f.x[["d_1259"]]) + as.numeric(f.x[["d_older"]]), 
	           as.numeric(f.x[["d_011"]]) + as.numeric(f.x[["d_1259"]]) ) )
	
	else
	
	return(c(f.x[["d"]] , f.x[["d_u5"]]) )

	}

x[, c("d", "d_u5")] <- t (apply(x, 1, f.recode) )
	

# add person-time variables to dataset, depending on the questionnaire
f.ptime <- function (f.x) {
	
	if ( (f.x[["questionnaire"]] == "current_1") || (f.x[["questionnaire"]] == "current_3") ) {
		# person-time = n of people in hh * 90 days
		# person-time under5 = (n under 5y in hh + half of deaths) * 90 days
		return( c(as.numeric(f.x[["n"]]) * 90, (as.numeric(f.x[["n_u5"]]) + as.numeric(f.x[["d_u5"]])/2) * 90) )
		
		}

	if (f.x[["questionnaire"]] == "current_2") {
		# person-time = n of people in hh* 90 days
		# person-time under5 = (n under 5y in hh + half of deaths) * 90 days
		# a finer analysis is done below for this class of questionnaire
		return( c(as.numeric(f.x[["n"]]) * 90 + as.numeric(f.x[["d"]]), as.numeric(f.x[["n"]]) * 0.2 * 90 + as.numeric(f.x[["d_u5"]]) * 90/2 ) )
		
		}
			
	if (f.x[["questionnaire"]] == "smart") {
		# person-time = (n of people in hh - half of the arrivals + half of the exits) * 90 days
		# person-time under5 = (n under 5y in hh - half of the arrivals + half of the exits) * 90 days
		return( c( (as.numeric(f.x[["n"]]) - as.numeric(f.x[["b"]])/2 - as.numeric(f.x[["j"]])/2 + as.numeric(f.x[["d"]])/2 + as.numeric(f.x[["l"]])/2 ) * 90, 
		           (as.numeric(f.x[["n_u5"]]) - as.numeric(f.x[["b"]])/2 - as.numeric(f.x[["j_u5"]])/2 + as.numeric(f.x[["d_u5"]])/2 + as.numeric(f.x[["l_u5"]])/2 ) * 90 ) )	
	
		}	
		
	}

x[, c("ptime", "ptime_u5")] <- t (apply(x, 1, f.ptime) )
	

# make sure numeric variables are actually numeric
for (i in c("cluster", "hh", "n", "n_u5", "j", "j_u5", "l", "l_u5", "b", "d", "d_u5", "d_older", "d_011", "d_1259", "ptime", "ptime_u5") ) {
	
	x[, i] <- as.numeric(x[, i] )

	}
	
	
	
#.........................................................................................
### Clean data

# generate analysability variable for each observation, with default being yes
x[, "analysable"] <- "yes"

# function to clean survey datasets
f.clean <- function (f.x) {
	
	out <- "yes"
	
	# set analysable to no if one or more of the following conditions are met:
	if (( (is.na(f.x[["n"]]) == F ) 		& 	(as.numeric(f.x[["n"]]) == 0) ) 		|
		( (is.na(f.x[["n"]]) == F ) 		& 	(as.numeric(f.x[["n"]]) > 20) ) 		|
		( (is.na(f.x[["n_u5"]]) == F ) 		& 	(as.numeric(f.x[["n_u5"]]) > 10) ) 		|
		( (is.na(f.x[["j"]]) == F ) 		& 	(as.numeric(f.x[["j"]]) > 10) ) 		|
		( (is.na(f.x[["j_u5"]]) == F ) 		& 	(as.numeric(f.x[["j_u5"]]) > 5) ) 		|
		( (is.na(f.x[["l"]]) == F ) 		& 	(as.numeric(f.x[["l"]]) > 10) ) 		|	
		( (is.na(f.x[["l_u5"]]) == F ) 		& 	(as.numeric(f.x[["l_u5"]]) > 5) ) 		|
		( (is.na(f.x[["b"]]) == F ) 		& 	(as.numeric(f.x[["b"]]) > 5) ) 			|
		( (is.na(f.x[["d"]]) == F ) 		& 	(as.numeric(f.x[["d"]]) > 10) ) 		|
		( (is.na(f.x[["d_u5"]]) == F ) 		& 	(as.numeric(f.x[["d_u5"]]) > 5) ) 		|
		( (is.na(f.x[["d_older"]]) == F ) 	& 	(as.numeric(f.x[["d_older"]]) > 5) ) 	|
		( (is.na(f.x[["d_011"]]) == F ) 	& 	(as.numeric(f.x[["d_011"]]) > 2) ) 		|
		( (is.na(f.x[["d_1259"]]) == F ) 	& 	(as.numeric(f.x[["d_1259"]]) > 3) )     |
		( (is.na(f.x[["ptime"]]) == F ) 	& 	(as.numeric(f.x[["ptime"]]) < 1) )		|
		( (is.na(f.x[["ptime_u5"]]) == F ) 	& 	(as.numeric(f.x[["ptime_u5"]]) < 0) )		|
		( (is.na(f.x[["n"]]) == F ) 		& 	(is.na(f.x[["n_u5"]]) == F )	& 	( as.numeric(f.x[["n"]]) <= as.numeric(f.x[["n_u5"]]) ) )
		
	   )
	out <- "no"
	   
	# set analysable to no if the following key variables are missing (depending on type of questionnaire):
	if (f.x[["questionnaire"]] == "current_1") {
	
		if(	(is.na(f.x[["cluster"]]) == T ) 	|
			(is.na(f.x[["n"]]) == T ) 			|
			(is.na(f.x[["n_u5"]]) == T ) 		|
			(is.na(f.x[["d_011"]]) == T ) 		|
			(is.na(f.x[["d_1259"]]) == T ) 		|
			(is.na(f.x[["d_older"]]) == T )     |
			(is.na(f.x[["ptime"]]) == T ) 
		   )
		out <- "no"
		
		}

	if (f.x[["questionnaire"]] == "current_2") {
	
		if(	(is.na(f.x[["cluster"]]) == T ) 	|
			(is.na(f.x[["n"]]) == T ) 			|
			(is.na(f.x[["d_011"]]) == T ) 		|
			(is.na(f.x[["d_1259"]]) == T ) 		|
			(is.na(f.x[["d_older"]]) == T )		|
			(is.na(f.x[["ptime"]]) == T ) 
		   )
		out <- "no"

		}
		
	if (f.x[["questionnaire"]] == "current_3") {
	
		if(	(is.na(f.x[["cluster"]]) == T ) 	|
			(is.na(f.x[["n"]]) == T ) 			|
			(is.na(f.x[["n_u5"]]) == T ) 		|
			(is.na(f.x[["d"]]) == T ) 			|
			(is.na(f.x[["d_u5"]]) == T )		|
			(is.na(f.x[["ptime"]]) == T ) 			
		  )
		out <- "no"
		
		}
		
	if (f.x[["questionnaire"]] == "smart") {
	
		if(	(is.na(f.x[["cluster"]]) == T ) 	|
			(is.na(f.x[["n"]]) == T ) 			|
			(is.na(f.x[["n_u5"]]) == T ) 		|
			(is.na(f.x[["d"]]) == T ) 			|
			(is.na(f.x[["d_u5"]]) == T )		|
			(is.na(f.x[["ptime"]]) == T ) 				
		  )
		out <- "no"
	
		}	
	
	return(out)
	
	}

# apply function to dataframe
x[, "analysable"] <- apply(x, 1, f.clean)


# make sure numeric variables are actually numeric
for (i in c("cluster", "hh", "n", "n_u5", "j", "j_u5", "l", "l_u5", "b", "d", "d_u5", "d_older", "d_011", "d_1259", "ptime", "ptime_u5") ) {
	
	x[, i] <- as.numeric(x[, i] )

	}


#.........................................................................................
### Analyse data

# create results dataset	
results.vars <- c(  "deaths_lshtm", "deaths_u5_lshtm", "deaths_u1_lshtm", "prop_deaths_u5", "prop_deathsu5_u1",
					"cdr_lshtm_est", "cdr_lshtm_lci", "cdr_lshtm_uci", "cdr_lshtm_deff",
					"u5dr_lshtm_est", "u5dr_lshtm_lci", "u5dr_lshtm_uci", "u5dr_lshtm_deff",
					"births", "cbr", "arrival_rate", "u5arrival_rate", "departure_rate", "u5departure_rate",
					"mean_hh_size", "mean_hh_size_u5", "prop_hh_u5" )

results <- metadata

results[, results.vars] <- NA

	
# function to perform analysis on each survey
f.analyse <- function(f.metadata, f.x) {
	
	print(paste("now analysing: ", f.metadata[["survey_id"]] ) )
	
	# capture dataset being analysed
	f.xi <- subset(f.x, survey_id==f.metadata[["survey_id"]])
	
	# restrict analysis to analysable observations and variables needed - reconverting these to numeric
	f.xi <- subset(f.xi, analysable=="yes")
	
	# make sure numeric variables are actually numeric just to be sure
	for (i in c("cluster", "hh", "n", "n_u5", "j", "j_u5", "l", "l_u5", "b", "d", "d_u5", "d_older", "d_011", "d_1259", "ptime", "ptime_u5") ) {
	
		f.xi[, i] <- as.numeric(f.xi[, i] )

		}

	# analysis of cluster surveys
	if (f.xi[1, "design"] == "cluster" ) {
	
		# specify survey design
		sdesign.cdr <- svydesign(id = ~cluster, data = f.xi)
		sdesign.u5dr <- svydesign(id = ~cluster, data = subset(f.xi, ptime_u5>0 ) )		
			
		return( c(
			#deaths_lshtm
			sum(f.xi[, "d"], na.rm=TRUE) ,
			#deaths_u5_lshtm
			sum(f.xi[, "d_u5"], na.rm=TRUE) ,		
			#deaths_u1_lshtm
			ifelse(sum(f.xi[, "d_011"], na.rm=TRUE) == 0, NA, sum(f.xi[, "d_011"], na.rm=TRUE) ) ,				
			#prop_deaths_u5
			sum(f.xi[, "d_u5"], na.rm=TRUE) / sum(f.xi[, "d"], na.rm=TRUE) ,
			#prop_deathsu5_u1
			ifelse(sum(f.xi[, "d_011"], na.rm=TRUE) == 0, NA, sum(f.xi[, "d_011"], na.rm=TRUE) / sum(f.xi[, "d_u5"], na.rm=TRUE) ) ,
			#cdr_lshtm_est per 10,000 p-days
			ifelse(sum(f.xi[, "d"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[1]] ) * 10000) ,
			#cdr_lshtm_lci
			ifelse(sum(f.xi[, "d"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[1]]
			   - 1.96*summary(svyglm(d~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[2]]) * 10000) , 
			#cdr_lshtm_uci
			ifelse(sum(f.xi[, "d"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[1]]
			   + 1.96*summary(svyglm(d~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[2]]) * 10000) , 
			#cdr_lshtm_deff
			NA , #TO BE CORRECTED!!!!!!!!!!!!!!!!!!!!!!!!
			#u5dr_lshtm_est per 10,000 p-days
			ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]] ) * 10000) ,
			#u5dr_lshtm_lci
			ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]]
			   - 1.96*summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[2]]) * 10000) , 		
			#u5dr_lshtm_uci
			ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]] 
			   + 1.96*summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[2]]) * 10000) , 		
			#u5dr_lshtm_deff
			NA , #TO BE CORRECTED!!!!!!!!!!!!!!!!!!!!!!!!		
			#births
			ifelse(sum(f.xi[, "b"], na.rm=TRUE) == 0, NA, sum(f.xi[, "b"], na.rm=TRUE) ) ,
			#cbr per 1000 p-years
			ifelse(sum(f.xi[, "b"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(b~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[1]] ) * 1000 * 365) ,
			#arrival_rate per 10,000 p-days
			ifelse(sum(f.xi[, "j"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(j~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[1]] ) * 10000) ,		
			#under 5y arrival_rate per 10,000 p-days
			ifelse(sum(f.xi[, "j_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(j_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]] ) * 10000) ,			
			#departure_rate per 10,000 p-days
			ifelse(sum(f.xi[, "l"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(l~NULL, sdesign.cdr, family="poisson", offset=log(ptime) ))$coefficients[[1]] ) * 10000) ,	
			#under 5y departure_rate per 10,000 p-days
			ifelse(sum(f.xi[, "l_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(l_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]] ) * 10000) ,			
			#mean_hh_size
			mean(f.xi[, "n"], na.rm=TRUE) ,
			#mean_hh_size_u5
			ifelse(sum(f.xi[, "n_u5"], na.rm=TRUE) == 0, NA, mean(f.xi[, "n_u5"], na.rm=TRUE) ) ,
			#prop_hh_u5
			ifelse(sum(f.xi[, "n_u5"], na.rm=TRUE) == 0, NA, mean(f.xi[, "n_u5"], na.rm=TRUE) / mean(f.xi[, "n"], na.rm=TRUE) )		
		))
	
		}

	else

	# analysis of exhaustive surveys	
		{
	
		return( c(
			#deaths_lshtm
			sum(f.xi[, "d"], na.rm=TRUE) ,
			#deaths_u5_lshtm
			sum(f.xi[, "d_u5"], na.rm=TRUE) ,		
			#deaths_u1_lshtm
			ifelse(sum(f.xi[, "d_011"], na.rm=TRUE) == 0, NA, sum(f.xi[, "d_011"], na.rm=TRUE) ) ,				
			#prop_deaths_u5
			sum(f.xi[, "d_u5"], na.rm=TRUE) / sum(f.xi[, "d"], na.rm=TRUE) ,
			#prop_deathsu5_u1
			ifelse(sum(f.xi[, "d_011"], na.rm=TRUE) == 0, NA, sum(f.xi[, "d_011"], na.rm=TRUE) / sum(f.xi[, "d_u5"], na.rm=TRUE) ) ,
			#cdr_lshtm_est per 10,000 p-days
			ifelse(sum(f.xi[, "d"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "d"], na.rm=TRUE) / sum(f.xi[, "ptime"], na.rm=TRUE) ) * 10000 ) ,
			#cdr_lshtm_lci
			ifelse(sum(f.xi[, "d"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "d"], na.rm=TRUE) / sum(f.xi[, "ptime"], na.rm=TRUE) ) * 10000
			   / exp(1.96/( sqrt(sum(f.xi[, "d"], na.rm=TRUE) ) ) ) ) , 
			#cdr_lshtm_uci
			ifelse(sum(f.xi[, "d"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "d"], na.rm=TRUE) / sum(f.xi[, "ptime"], na.rm=TRUE) ) * 10000
			   * exp(1.96/( sqrt(sum(f.xi[, "d"], na.rm=TRUE) ) ) ) ) , 
			#cdr_lshtm_deff
			1 ,
			#u5dr_lshtm_est per 10,000 p-days
			ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "d_u5"], na.rm=TRUE) / sum(f.xi[, "ptime_u5"], na.rm=TRUE) ) * 10000) ,
			#u5dr_lshtm_lci
			ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "d_u5"], na.rm=TRUE) / sum(f.xi[, "ptime_u5"], na.rm=TRUE) ) * 10000
			   / exp(1.96/( sqrt(sum(f.xi[, "d_u5"], na.rm=TRUE) ) ) ) ), 
			#u5dr_lshtm_uci
			ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "d_u5"], na.rm=TRUE) / sum(f.xi[, "ptime_u5"], na.rm=TRUE) ) * 10000
			   * exp(1.96/( sqrt(sum(f.xi[, "d_u5"], na.rm=TRUE) ) ) ) ), 
			#u5dr_lshtm_deff
			1 ,	
			#births
			ifelse(sum(f.xi[, "b"], na.rm=TRUE) == 0, NA, sum(f.xi[, "b"], na.rm=TRUE) ) ,
			#cbr per 1000 p-years
			ifelse(sum(f.xi[, "b"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "b"], na.rm=TRUE) / sum(f.xi[, "ptime"], na.rm=TRUE) ) * 1000 * 365) ,
			#arrival_rate per 10,000 p-days
			ifelse(sum(f.xi[, "j"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "j"], na.rm=TRUE) / sum(f.xi[, "ptime"], na.rm=TRUE) ) * 10000) ,	
			#under 5y arrival_rate per 10,000 p-days
			ifelse(sum(f.xi[, "j_u5"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "j_u5"], na.rm=TRUE) / sum(f.xi[, "ptime_u5"], na.rm=TRUE) ) * 10000) ,		
			#departure_rate per 10,000 p-days
			ifelse(sum(f.xi[, "l"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "l"], na.rm=TRUE) / sum(f.xi[, "ptime"], na.rm=TRUE) ) * 10000) ,
			#under 5y departure_rate per 10,000 p-days
			ifelse(sum(f.xi[, "l_u5"], na.rm=TRUE) == 0, NA, (sum(f.xi[, "l_u5"], na.rm=TRUE) / sum(f.xi[, "ptime_u5"], na.rm=TRUE) ) * 10000) ,		
			#mean_hh_size
			mean(f.xi[, "n"], na.rm=TRUE) ,
			#mean_hh_size_u5
			ifelse(sum(f.xi[, "n_u5"], na.rm=TRUE) == 0, NA, mean(f.xi[, "n_u5"], na.rm=TRUE) ) ,
			#prop_hh_u5
			ifelse(sum(f.xi[, "n_u5"], na.rm=TRUE) == 0, NA, mean(f.xi[, "n_u5"], na.rm=TRUE) / mean(f.xi[, "n"], na.rm=TRUE) )
			))	
		
		}
	}

# analyse data
	
results[, results.vars] <- t (apply(metadata, 1, f.analyse, x ) )


#.........................................................................................
### Re-analyse surveys without data on under 5y hh size

for (i in as.vector(subset(results, is.finite(prop_hh_u5)==FALSE )[, "survey_id"] )) {

	print(paste("now analysing: ", i ) )
	
	# capture dataset being analysed
	f.xi <- subset(x, survey_id==i)
	
	# restrict analysis to analysable observations and variables needed - reconverting these to numeric
	f.xi <- subset(f.xi, analysable=="yes")
	
	# make sure numeric variables are actually numeric just to be sure
	for (j in c("cluster", "hh", "n", "n_u5", "j", "j_u5", "l", "l_u5", "b", "d", "d_u5", "d_older", "d_011", "d_1259", "ptime", "ptime_u5") ) {
	
	f.xi[, j] <- as.numeric(f.xi[, j] )
	
	}
	
	# figure out which livelihood-specific set of data on proportion under 5y needs to be used (Somalia only)
	liv <- results[which(results[, "survey_id"]==i), "livelihood"]	
	prop <- subset(results, is.finite(prop_hh_u5) & livelihood == as.character(liv) & location1 == "Somalia" )[, "prop_hh_u5"]
	
	# do 1000 replicates of analysis sampling each time a random value of proporion under 5y
	out <- replicate(1000, {	
		
		# generate person-time under 5y based on random value from empirical data on the proportion under 5y for that livelihood
		f.xi[, "ptime_u5"] <- f.xi[, "ptime"] * sample(prop, 1)
			
		# specify survey design
		sdesign.u5dr <- svydesign(id = ~cluster, data = subset(f.xi, ptime_u5 > 0) )	
		
		return(c(
				#u5dr_lshtm_est per 10,000 p-days
				ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]] ) * 10000) ,
				#u5dr_lshtm_lci
				ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]]
				   - 1.96*summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[2]]) * 10000) , 		
				#u5dr_lshtm_uci
				ifelse(sum(f.xi[, "d_u5"], na.rm=TRUE) == 0, NA, exp(summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[1]] 
				   + 1.96*summary(svyglm(d_u5~NULL, sdesign.u5dr, family="poisson", offset=log(ptime_u5) ))$coefficients[[2]]) * 10000) , 		
				#u5dr_lshtm_deff
			NA #TO BE CORRECTED!!!!!!!!!!!!!!!!!!!!!!!!			
			) )
		} )
	
	# take median of 1000 replicates
	results[which(results[, "survey_id"]==i), "u5dr_lshtm_est"]  	<- median(t(out)[, 1])
	results[which(results[, "survey_id"]==i), "u5dr_lshtm_lci"]  	<- median(t(out)[, 2])
	results[which(results[, "survey_id"]==i), "u5dr_lshtm_uci"]  	<- median(t(out)[, 3])
	results[which(results[, "survey_id"]==i), "u5dr_lshtm_deff"]  	<- median(t(out)[, 4])
	
}

#.........................................................................................
### Format and write results

results[, c(  "prop_deaths_u5", "prop_deathsu5_u1",
			  "cdr_lshtm_est", "cdr_lshtm_lci", "cdr_lshtm_uci", "cdr_lshtm_deff",
			  "u5dr_lshtm_est", "u5dr_lshtm_lci", "u5dr_lshtm_uci", "u5dr_lshtm_deff",
			  "cbr", "arrival_rate", "u5arrival_rate", "departure_rate", "u5departure_rate",
			  "mean_hh_size", "mean_hh_size_u5", "prop_hh_u5" )] <-
	round(results[, c(  "prop_deaths_u5", "prop_deathsu5_u1",
			  "cdr_lshtm_est", "cdr_lshtm_lci", "cdr_lshtm_uci", "cdr_lshtm_deff",
			  "u5dr_lshtm_est", "u5dr_lshtm_lci", "u5dr_lshtm_uci", "u5dr_lshtm_deff",
			  "cbr", "arrival_rate", "u5arrival_rate", "departure_rate", "u5departure_rate",
			  "mean_hh_size", "mean_hh_size_u5", "prop_hh_u5" )], 2)


write.csv(results, "results_mortality_validation.csv")

